{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% trans "Edit Security Service" %}{% endblock %}

{% block main %}
    {% include 'project/security_services/_update.html' %}
{% endblock %}
